pub async fn new(
settings: Settings,
display: impl Display,
compatible_window: impl Window,
shell: Shell,
) -> Result<Compositor, Error>Expand description
Creates a Compositor with the given Settings and window.
pub async fn new(
settings: Settings,
display: impl Display,
compatible_window: impl Window,
shell: Shell,
) -> Result<Compositor, Error>Creates a Compositor with the given Settings and window.